
#include <stdio.h>
#include "em_device.h"
#include "em_chip.h"
#include "em_cmu.h"


volatile uint32_t msTicks; /* counts 1ms timeTicks */

void Delay(uint32_t dlyTicks);

/**************************************************************************//**
 * @brief SysTick_Handler
 * Interrupt Service Routine for system tick counter
 *****************************************************************************/
void SysTick_Handler(void)
{
  msTicks++;       /* increment counter necessary in Delay()*/
}

/**************************************************************************//**
 * @brief Delays number of msTick Systicks (typically 1 ms)
 * @param dlyTicks Number of ticks to delay
 *****************************************************************************/
void Delay(uint32_t dlyTicks)
{
  uint32_t curTicks;

  curTicks = msTicks;
  while ((msTicks - curTicks) < dlyTicks) ;
}

/**************************************************************************//**
 * @brief  Main function
 *****************************************************************************/
int main(void)
{
  
  char rec_char;

  /* Setup SysTick Timer for 1 msec interrupts  */
  if (SysTick_Config(CMU_ClockFreqGet(cmuClock_CORE) / 1000)) while (1) ;
  
  /*Added printf */
  printf("Hello EFM32 User\n\r");
  Delay(500);

  /* Infinite -  loop */
  while (1)
  {
    printf("Please enter a char/num:\n\r");
    scanf("%c", &rec_char);
    printf("Character received: %c\n\r", rec_char);
    Delay(500);                            
  }
}
                 